@@ -62,6 +62,7 @@ def request(url, params={}, method='GET', body=None, headers={},
     NOTE: to call HTTPS URLs, Python must have been built with SSL support."""
     _urlparts = urlparse.urlparse(url)
     _host = _urlparts.netloc
+    _matrix_params = _urlparts.params
     _params = ''
     if len(_urlparts.query) > 0:
         _params = _urlparts.query
@@ -70,6 +71,8 @@ def request(url, params={}, method='GET', body=None, headers={},
             _params += '&'
         _params += urllib.urlencode(params)
     _path = _urlparts.path
+    if _matrix_params:
+        _path += ';%s' % _matrix_params
     if len(_params) > 0:
         _path += '?'
         _path += _params
